import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { tsv, csv, arc, pie, scaleBand, scaleLinear, max } from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/sophburke/94a3c3f9bcb3186cf1eb43f4044dbe03/raw/7e660f27071241878841ca3f03bde3fec3e443ce/hx-mitx-course-person-dataset2013-10k.csv'
const width = 960;
const height = 500;

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
      d.Course = +d['2020'];
      return d;
    };
    tsv(csvUrl, row).then(data => {
      setData;
              });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  console.log(data[0]);

  const yScale = scaleBand()
    .domain(data.map(d => d.Course))
    .range([0, height]);

  const xScale = scaleLinear()
  .domain([0, max(data, d => d.nplay-video)])
  .range([0, width]);

  return (
  <svg width={width} height={height}>
			{data.map(d => (
          <rect
                 x={0} 
                 y={yScale(d.Country)} 
                 width={xScale(d.Population)} 
                 height={yScale.bandwidth()}
                 />
         ))}
  </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
